# SPDX-FileCopyrightText: 2025-present Datadog, Inc. <dev@datadoghq.com>
#
# SPDX-License-Identifier: MIT
from __future__ import annotations

import sys
from typing import TYPE_CHECKING

import click

from dda.cli.base import dynamic_command

if TYPE_CHECKING:
    from dda.cli.application import Application


@dynamic_command(short_help="Serve documentation", features=["self-dev"])
@click.option(
    "--dirty",
    is_flag=True,
    help="Speed up reload time by only rebuilding edited pages (based on modified time). For development only.",
)
@click.pass_obj
def cmd(app: Application, *, dirty: bool) -> None:
    """
    Serve documentation.
    """
    command = [sys.executable, "-m", "hatch", "run", "docs:serve"]
    if dirty:
        app.display_warning(
            "Using dirty reload - NOTE: When editing autogenerated content (such as docstrings for API documentation), "
            "re-save the `.md` file that contains the output to trigger a refresh."
        )
        command.append("--dirtyreload")

    app.subprocess.exit_with_command(command)
